@@ -37,6 +37,8 @@ WSGI environ.
    :member-order: bysource
 
 
+.. _wsgi-media-router:
+
 Media Router
 =====================
 
@@ -144,14 +146,16 @@ class RouterType(type):
 
 
 class Router(RouterType('RouterBase', (object,), {})):
-    '''A WSGI middleware to handle client requests on multiple
-:ref:`routes <apps-wsgi-route>`. The user must implement the HTTP methods
-required by her application. For example if the route needs to serve a ``GET``
+    '''A :ref:`WSGI middleware <wsgi-middleware>` to handle client requests
+on multiple :ref:`routes <apps-wsgi-route>`.
+
+The user must implement the HTTP methods
+required by the application. For example if the route needs to serve a ``GET``
 request, the ``get(self, request)`` method must be implemented.
 
 :param rule: String used for creating the :attr:`route` of this
     :class:`Router`.
-:param routes: Optionals :class:`Router` instances which are added to the
+:param routes: Optional :class:`Router` instances which are added to the
     children :attr:`routes` of this router.
 :param parameters: Optional parameters for this router. They are stored in the
     :attr:`parameters` attribute. If a ``response_content_types`` value is
@@ -218,9 +222,12 @@ request, the ``get(self, request)`` method must be implemented.
 
     @property
     def name(self):
-        '''The name of this :class:`Router`. This attribute can be specified
-during initialisation. If available, it can be used to retrieve a child router
-by name via the :meth:`get_route` method.'''
+        '''The name of this :class:`Router`.
+
+        This attribute can be specified during initialisation.
+        If available, it can be used to retrieve a child router
+        by name via the :meth:`get_route` method.
+        '''
         return self._name
 
     @property
@@ -244,8 +251,9 @@ in the :attr:`response_content_types` list.'''
 
     @property
     def creation_count(self):
-        '''Integer for sorting :class:`Router` by creation. It is autogenerated
-during :class:`Router` initialisation.'''
+        '''Integer for sorting :class:`Router` by creation.
+
+        Auto-generated during initialisation.'''
         return self._creation_count
 
     @property
@@ -320,26 +328,24 @@ during :class:`Router` initialisation.'''
     def __repr__(self):
         return self.route.__repr__()
 
-    def __call__(self, environ, start_response):
+    def __call__(self, environ, start_response=None):
         path = environ.get('PATH_INFO') or '/'
         path = path[1:]
         router_args = self.resolve(path)
         if router_args:
             router, args = router_args
-            return router.response(environ, start_response, args)
+            return router.response(environ, args)
         else:
             if self.route.is_leaf:
                 if path.endswith('/'):
                     router_args = self.resolve(path[:-1])
                     if router_args is not None:
-                        return self.redirect(environ, start_response,
-                                             '/%s' % path[:-1])
+                        return self.redirect(environ, '/%s' % path[:-1])
             else:
                 if not path.endswith('/'):
                     router_args = self.resolve('%s/' % path)
                     if router_args is not None:
-                        return self.redirect(environ, start_response,
-                                             '/%s/' % path)
+                        return self.redirect(environ, '/%s/' % path)
 
     def resolve(self, path, urlargs=None):
         '''Resolve a path and return a ``(handler, urlargs)`` tuple or
@@ -361,7 +367,7 @@ during :class:`Router` initialisation.'''
             return self, match
 
     @async(get_result=True)
-    def response(self, environ, start_response, args):
+    def response(self, environ, args):
         '''Once the :meth:`resolve` method has matched the correct
 :class:`Router` for serving the request, this matched router invokes
 this method to produce the WSGI response.'''
@@ -387,7 +393,7 @@ this method to produce the WSGI response.'''
             yield callable(request)
 
     @async(get_result=True)
-    def redirect(self, environ, start_response, path):
+    def redirect(self, environ, path):
         request = wsgi_request(environ, self)
         environ['pulsar.cache'] = yield multi_async(request.cache)
         raise HttpRedirect(path)
